@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef STEP_PROPERTIESBROWSER_H
@@ -21,6 +9,7 @@
 
 #include <QDockWidget>
 #include <QItemDelegate>
+
 class PropertiesBrowserModel;
 class WorldModel;
 class QModelIndex;
@@ -33,8 +22,8 @@ class PropertiesBrowserDelegate: public QItemDelegate
 {
     Q_OBJECT
 public:
-    explicit PropertiesBrowserDelegate(QObject* parent = 0):
-            QItemDelegate(parent), _editor(NULL), _updating(false) {}
+    explicit PropertiesBrowserDelegate(QObject* parent = nullptr):
+            QItemDelegate(parent), _editor(nullptr), _updating(false) {}
     QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& option,
                            const QModelIndex& index) const override;
     void setEditorData(QWidget* editor, const QModelIndex& index) const override;
@@ -59,7 +48,7 @@ class PropertiesBrowser: public QDockWidget
     Q_OBJECT
 
 public:
-    explicit PropertiesBrowser(WorldModel* worldModel, QWidget* parent = 0);
+    explicit PropertiesBrowser(WorldModel* worldModel, QWidget* parent = nullptr);
 
 public slots:
     void settingsChanged();
